@@ -1,5 +1,6 @@
 import hashlib
 import inspect
+import json
 import os
 import re
 from pathlib import Path
@@ -130,7 +131,7 @@ def create_event_external_id(
 ) -> str:
 
     to_be_hashed = model_name + model_version + ts_external_id + str(start_time) + str(end_time)
-    hash_object = hashlib.md5(to_be_hashed.encode())
+    hash_object = hashlib.md5(to_be_hashed.encode())  # nosec
     return hash_object.hexdigest()
 
 
@@ -142,7 +143,14 @@ def retrieve_dependency(model_name: str) -> str:
 
 def retrieve_window_size(client: CogniteClient) -> int:
     asset_id = retrieve_model_asset_id(client)
-    schedule = eval(client.assets.retrieve(asset_id).metadata.get("schedule"))
+    schedule = json.loads(client.assets.retrieve(asset_id).metadata.get("schedule"))
     if schedule.get("windowSize"):
         return int(schedule.get("windowSize"))
     return 0
+
+
+def extract_data(client: CogniteClient, data: Dict) -> Dict:
+    schedule_asset_external_id = data["schedule_asset_ext_id"]
+    schedule_asset = client.assets.retrieve(external_id=schedule_asset_external_id)
+    data = json.loads(schedule_asset.metadata("data"))
+    return data
